@@ -15,7 +15,7 @@ from torch.optim import Adam
 
 from torchvision import transforms as T, utils
 
-from einops import rearrange, reduce
+from einops import rearrange, reduce, repeat
 from einops.layers.torch import Rearrange
 
 from PIL import Image
@@ -945,7 +945,7 @@ class Trainer(object):
     def fid_score(self, real_samples, fake_samples):
 
         if self.channels == 1:
-            real_samples, fake_samples = map(lambda t: rearrange(t, 'b 1 ... -> b c ...', c = 3), (real_samples, fake_samples))
+            real_samples, fake_samples = map(lambda t: repeat(t, 'b 1 ... -> b c ...', c = 3), (real_samples, fake_samples))
 
         min_batch = min(real_samples.shape[0], fake_samples.shape[0])
         real_samples, fake_samples = map(lambda t: t[:min_batch], (real_samples, fake_samples))
